@@ -1,6 +1,16 @@
-__version__ = "2.2.1"
+__version__ = "2.3.4"
 
 
+import os
+
+_dir = os.path.dirname(__file__)
+_camlibs = os.path.join(_dir, 'camlibs')
+if os.path.isdir(_camlibs):
+    os.environ['CAMLIBS'] = _camlibs
+_iolibs = os.path.join(_dir, 'iolibs')
+if os.path.isdir(_iolibs):
+    os.environ['IOLIBS'] = _iolibs
+
 class GPhoto2Error(Exception):
     """Exception raised by gphoto2 library errors
 
@@ -26,4 +36,8 @@ from gphoto2.result import *
 from gphoto2.version import *
 from gphoto2.widget import *
 
+_locale = os.path.join(_dir, 'locale')
+if os.path.isdir(_locale):
+    gphoto2.abilities_list.gp_init_localedir(_locale)
+
 __all__ = dir()
